@@ -1,12 +1,11 @@
-import pytest
 import factory
+import pytest
+from ckan.tests.factories import CKANFactory, Resource, fake
 from pytest_factoryboy import register
-from ckan.tests.factories import CKANFactory, fake, Resource
 
 from ckanext.check_link.model import Report
 
 
-
 @pytest.fixture
 def clean_db(reset_db, migrate_db_for):
     reset_db()
